@@ -46,107 +46,107 @@ sub AUTOLOAD {
 
 
 @DEVICECONTROL = qw(
-newpl
-selectpl
-deletepl
-parampl
-closepl
-openpl
-flushpl
+pl_newpl
+pl_selectpl
+pl_deletepl
+pl_parampl
+pl_closepl
+pl_openpl
+pl_flushpl
    );
 
 @MAPPING = qw (
-fconcat
-frotate
-fscale
-ftranslate
+pl_fconcat
+pl_frotate
+pl_fscale
+pl_ftranslate
 	       );
 
 @ATTRIBUTES = qw (
-bgcolor
-bgcolorname
-linemod
-capmod
-color
-colorname
-filltype
-fillcolor
-fillcolorname
-fontname
-fontsize
-havecap
-joinmod
-pencolor
-pencolorname
-linewidth
-labelwidth	  
-restorestate
-savestate
-textangle
+pl_bgcolor
+pl_bgcolorname
+pl_linemod
+pl_capmod
+pl_color
+pl_colorname
+pl_filltype
+pl_fillcolor
+pl_fillcolorname
+pl_fontname
+pl_fontsize
+pl_havecap
+pl_joinmod
+pl_pencolor
+pl_pencolorname
+pl_linewidth
+pl_labelwidth	  
+pl_restorestate
+pl_savestate
+pl_textangle
 
 );
 
 @GENERAL = qw(
-label
-erase
-outfile
-endpath
+pl_label
+pl_erase
+pl_outfile
+pl_endpath
      );
 
 @INTLOWLEVEL = qw (
-arc
-box
-circle
-cont
-line
-move
-point
-space
-alabel
-arcrel
-boxrel
-circlerel
-contrel
-ellarc
-ellarcrel
-ellipse
-ellipserel
-linerel
-marker
-markerrel
-moverel
-pointrel
-space2
+pl_arc
+pl_box
+pl_circle
+pl_cont
+pl_line
+pl_move
+pl_point
+pl_space
+pl_alabel
+pl_arcrel
+pl_boxrel
+pl_circlerel
+pl_contrel
+pl_ellarc
+pl_ellarcrel
+pl_ellipse
+pl_ellipserel
+pl_linerel
+pl_marker
+pl_markerrel
+pl_moverel
+pl_pointrel
+pl_space2
 );
 
 @FLOATLOWLEVEL = qw (
-ffontname
-ffontsize
-flabelwidth
-ftextangle
-farc
-farcrel
-fbox
-fboxrel
-fcircle
-fcirclerel
-fcont
-fcontrel
-fellarc
-fellarcrel
-fellipse
-fellipserel
-fline
-flinerel
-flinewidth
-fmarker
-fmarkerrel
-fmove
-fmoverel
-fpoint
-fpointrel
-fspace
-fspace2
+pl_ffontname
+pl_ffontsize
+pl_flabelwidth
+pl_ftextangle
+pl_farc
+pl_farcrel
+pl_fbox
+pl_fboxrel
+pl_fcircle
+pl_fcirclerel
+pl_fcont
+pl_fcontrel
+pl_fellarc
+pl_fellarcrel
+pl_fellipse
+pl_fellipserel
+pl_fline
+pl_flinerel
+pl_flinewidth
+pl_fmarker
+pl_fmarkerrel
+pl_fmove
+pl_fmoverel
+pl_fpoint
+pl_fpointrel
+pl_fspace
+pl_fspace2
 );
 
 
@@ -199,10 +199,10 @@ will write some centered text.
 
 None of the libplot functions is exported by default. If you do not 
 import any functions 
-you must prepend the module name to each function.  To call the openpl() 
+you must prepend the module name to each function.  To call the pl_openpl() 
 function you would give,
 
-Graphics::Libplot::openpl();
+Graphics::Libplot::pl_openpl();
 
 
 However, if you include the library with
@@ -225,35 +225,47 @@ be added, and your scripts may need to be changed.
 
 =head1 EXAMPLES
 
-There are additional examples included in the source distribution.
+There are additional examples included in the source distribution. 
+(They are in /usr/doc/libplot-perl/examples on debian systems.)
 This example draws a spiraling box pattern.
 
- use Graphics::Libplot ':ALL';
- $SIZE=100;
- parampl ("BITMAPSIZE", "700x700");
- $handle = newpl("X", stdin, stdout, stderr); # open xwindow display
- selectpl($handle); 
- openpl();
- fspace(-$SIZE,-$SIZE, $SIZE, $SIZE); # specify user coord system 
- pencolorname ("blue");
- fontname("HersheySerif");
- $s = 10;
- $f = 10;
- $sf = 1- .0012;
- for($i=1;$i<3000;$i++){
-     fscale($sf,$sf);
-     fbox(60+$s*sin($i/$f),
-	  60+$s*sin($i/$f),
-	  75-$s*cos($i/$f),
-	  75-$s*cos($i/$f));
-    frotate(1);
- }
- closepl();
- selectpl(0);
- deletepl($handle);
 
-Substituting "ps" for "X" in the above example produces postscript
-on the standard output stream.
+use Graphics::Libplot ':ALL';
+
+# type of plotting device
+$device = 'X';
+if (@ARGV) {
+    $device = $ARGV[0];	
+    die "Uknown device: $ARGV[0]" unless $ARGV[0] =~ /^ps|X|fig$/;
+}
+
+{   # environment for local variables
+
+my $SIZE=100;
+my ($i,$f,$s,$sf);
+pl_parampl ("BITMAPSIZE", "700x700");
+$handle = pl_newpl($device, stdin, stdout, stderr); # open xwindow display
+pl_selectpl($handle); 
+pl_openpl();
+pl_fspace(-$SIZE,-$SIZE, $SIZE, $SIZE); # specify user coord system 
+pl_pencolorname ("blue");
+pl_fontname("HersheySerif");
+$s = 10;
+$f = 10;
+$sf = 1- .0012;
+for($i=1;$i<3000;$i++){
+    pl_fscale($sf,$sf);
+    pl_fbox(60+$s*sin($i/$f),
+	 60+$s*sin($i/$f),
+	 75-$s*cos($i/$f),
+	 75-$s*cos($i/$f));
+    pl_frotate(1);
+}
+
+}
+pl_closepl();
+pl_selectpl(0);
+pl_deletepl($handle);
 
 =head1 
 
